==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_entities/issuereturntransaction_001/IssueReturnTransaction.java <==

package net.datastream.schemas.mp_entities.issuereturntransaction_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.issuereturntransactionline_001.IssueReturnTransactionLines;
import net.datastream.schemas.mp_fields.ACTIVITYID;
import net.datastream.schemas.mp_fields.COSTCODEID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.MATERIALLISTID_Type;
import net.datastream.schemas.mp_fields.MULTIEQUIPSPLITINFOBATCH;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.PICKLIST_Type;
import net.datastream.schemas.mp_fields.PROJECTBUDGETID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.TRANSACTIONID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUERETURNTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROJECTBUDGET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PICKLISTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUETO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ADVICENUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIPSPLITINFOBATCH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/IssueReturnTransactionLine_001}IssueReturnTransactionLines"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "issuereturntype",
    "activityid",
    "jobsequence",
    "projectbudget",
    "equipmentid",
    "costcodeid",
    "storeid",
    "materiallistid",
    "picklistid",
    "departmentid",
    "transactiondate",
    "issueto",
    "advicenumber",
    "multiequipsplitinfobatch",
    "issueReturnTransactionLines"
})
@XmlRootElement(name = "IssueReturnTransaction")
public class IssueReturnTransaction {

    @XmlElement(name = "TRANSACTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "ISSUERETURNTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String issuereturntype;
    @XmlElement(name = "ACTIVITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYID activityid;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlElement(name = "PROJECTBUDGET", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROJECTBUDGETID_Type projectbudget;
    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "COSTCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected COSTCODEID_Type costcodeid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type storeid;
    @XmlElement(name = "MATERIALLISTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MATERIALLISTID_Type materiallistid;
    @XmlElement(name = "PICKLISTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PICKLIST_Type picklistid;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "TRANSACTIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME transactiondate;
    @XmlElement(name = "ISSUETO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type issueto;
    @XmlElement(name = "ADVICENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String advicenumber;
    @XmlElement(name = "MULTIEQUIPSPLITINFOBATCH", namespace = "http://schemas.datastream.net/MP_fields")
    protected MULTIEQUIPSPLITINFOBATCH multiequipsplitinfobatch;
    @XmlElement(name = "IssueReturnTransactionLines", namespace = "http://schemas.datastream.net/MP_entities/IssueReturnTransactionLine_001", required = true)
    protected IssueReturnTransactionLines issueReturnTransactionLines;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété transactionid.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Définit la valeur de la propriété transactionid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Obtient la valeur de la propriété issuereturntype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISSUERETURNTYPE() {
        return issuereturntype;
    }

    /**
     * Définit la valeur de la propriété issuereturntype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISSUERETURNTYPE(String value) {
        this.issuereturntype = value;
    }

    /**
     * Obtient la valeur de la propriété activityid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Définit la valeur de la propriété activityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Obtient la valeur de la propriété projectbudget.
     * 
     * @return
     *     possible object is
     *     {@link PROJECTBUDGETID_Type }
     *     
     */
    public PROJECTBUDGETID_Type getPROJECTBUDGET() {
        return projectbudget;
    }

    /**
     * Définit la valeur de la propriété projectbudget.
     * 
     * @param value
     *     allowed object is
     *     {@link PROJECTBUDGETID_Type }
     *     
     */
    public void setPROJECTBUDGET(PROJECTBUDGETID_Type value) {
        this.projectbudget = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété costcodeid.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Définit la valeur de la propriété costcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété materiallistid.
     * 
     * @return
     *     possible object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public MATERIALLISTID_Type getMATERIALLISTID() {
        return materiallistid;
    }

    /**
     * Définit la valeur de la propriété materiallistid.
     * 
     * @param value
     *     allowed object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public void setMATERIALLISTID(MATERIALLISTID_Type value) {
        this.materiallistid = value;
    }

    /**
     * Obtient la valeur de la propriété picklistid.
     * 
     * @return
     *     possible object is
     *     {@link PICKLIST_Type }
     *     
     */
    public PICKLIST_Type getPICKLISTID() {
        return picklistid;
    }

    /**
     * Définit la valeur de la propriété picklistid.
     * 
     * @param value
     *     allowed object is
     *     {@link PICKLIST_Type }
     *     
     */
    public void setPICKLISTID(PICKLIST_Type value) {
        this.picklistid = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété transactiondate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTRANSACTIONDATE() {
        return transactiondate;
    }

    /**
     * Définit la valeur de la propriété transactiondate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTRANSACTIONDATE(DATETIME value) {
        this.transactiondate = value;
    }

    /**
     * Obtient la valeur de la propriété issueto.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getISSUETO() {
        return issueto;
    }

    /**
     * Définit la valeur de la propriété issueto.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setISSUETO(PERSONID_Type value) {
        this.issueto = value;
    }

    /**
     * Obtient la valeur de la propriété advicenumber.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getADVICENUMBER() {
        return advicenumber;
    }

    /**
     * Définit la valeur de la propriété advicenumber.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setADVICENUMBER(String value) {
        this.advicenumber = value;
    }

    /**
     * Obtient la valeur de la propriété multiequipsplitinfobatch.
     * 
     * @return
     *     possible object is
     *     {@link MULTIEQUIPSPLITINFOBATCH }
     *     
     */
    public MULTIEQUIPSPLITINFOBATCH getMULTIEQUIPSPLITINFOBATCH() {
        return multiequipsplitinfobatch;
    }

    /**
     * Définit la valeur de la propriété multiequipsplitinfobatch.
     * 
     * @param value
     *     allowed object is
     *     {@link MULTIEQUIPSPLITINFOBATCH }
     *     
     */
    public void setMULTIEQUIPSPLITINFOBATCH(MULTIEQUIPSPLITINFOBATCH value) {
        this.multiequipsplitinfobatch = value;
    }

    /**
     * Obtient la valeur de la propriété issueReturnTransactionLines.
     * 
     * @return
     *     possible object is
     *     {@link IssueReturnTransactionLines }
     *     
     */
    public IssueReturnTransactionLines getIssueReturnTransactionLines() {
        return issueReturnTransactionLines;
    }

    /**
     * Définit la valeur de la propriété issueReturnTransactionLines.
     * 
     * @param value
     *     allowed object is
     *     {@link IssueReturnTransactionLines }
     *     
     */
    public void setIssueReturnTransactionLines(IssueReturnTransactionLines value) {
        this.issueReturnTransactionLines = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/issuereturntransaction_001/IssueReturnTransaction.java <==

package net.datastream.schemas.mp_entities.issuereturntransaction_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.issuereturntransactionline_001.IssueReturnTransactionLines;
import net.datastream.schemas.mp_fields.ACTIVITYID;
import net.datastream.schemas.mp_fields.COSTCODEID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.MATERIALLISTID_Type;
import net.datastream.schemas.mp_fields.MULTIEQUIPSPLITINFOBATCH;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.PICKLIST_Type;
import net.datastream.schemas.mp_fields.PROJECTBUDGETID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.TRANSACTIONID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUERETURNTYPE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROJECTBUDGET" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STOREID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PICKLISTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUETO" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ADVICENUMBER" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIPSPLITINFOBATCH" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/IssueReturnTransactionLine_001}IssueReturnTransactionLines"/>
 *       </sequence>
 *       <attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "issuereturntype",
    "activityid",
    "jobsequence",
    "projectbudget",
    "equipmentid",
    "costcodeid",
    "storeid",
    "materiallistid",
    "picklistid",
    "departmentid",
    "transactiondate",
    "issueto",
    "advicenumber",
    "multiequipsplitinfobatch",
    "issueReturnTransactionLines"
})
@XmlRootElement(name = "IssueReturnTransaction")
public class IssueReturnTransaction {

    @XmlElement(name = "TRANSACTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "ISSUERETURNTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String issuereturntype;
    @XmlElement(name = "ACTIVITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYID activityid;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlElement(name = "PROJECTBUDGET", namespace = "http://schemas.datastream.net/MP_fields")
    protected PROJECTBUDGETID_Type projectbudget;
    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "COSTCODEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected COSTCODEID_Type costcodeid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type storeid;
    @XmlElement(name = "MATERIALLISTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MATERIALLISTID_Type materiallistid;
    @XmlElement(name = "PICKLISTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PICKLIST_Type picklistid;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "TRANSACTIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME transactiondate;
    @XmlElement(name = "ISSUETO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type issueto;
    @XmlElement(name = "ADVICENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String advicenumber;
    @XmlElement(name = "MULTIEQUIPSPLITINFOBATCH", namespace = "http://schemas.datastream.net/MP_fields")
    protected MULTIEQUIPSPLITINFOBATCH multiequipsplitinfobatch;
    @XmlElement(name = "IssueReturnTransactionLines", namespace = "http://schemas.datastream.net/MP_entities/IssueReturnTransactionLine_001", required = true)
    protected IssueReturnTransactionLines issueReturnTransactionLines;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the transactionid property.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Sets the value of the transactionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Gets the value of the issuereturntype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISSUERETURNTYPE() {
        return issuereturntype;
    }

    /**
     * Sets the value of the issuereturntype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISSUERETURNTYPE(String value) {
        this.issuereturntype = value;
    }

    /**
     * Gets the value of the activityid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Sets the value of the activityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Gets the value of the projectbudget property.
     * 
     * @return
     *     possible object is
     *     {@link PROJECTBUDGETID_Type }
     *     
     */
    public PROJECTBUDGETID_Type getPROJECTBUDGET() {
        return projectbudget;
    }

    /**
     * Sets the value of the projectbudget property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROJECTBUDGETID_Type }
     *     
     */
    public void setPROJECTBUDGET(PROJECTBUDGETID_Type value) {
        this.projectbudget = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the costcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Sets the value of the costcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the materiallistid property.
     * 
     * @return
     *     possible object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public MATERIALLISTID_Type getMATERIALLISTID() {
        return materiallistid;
    }

    /**
     * Sets the value of the materiallistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public void setMATERIALLISTID(MATERIALLISTID_Type value) {
        this.materiallistid = value;
    }

    /**
     * Gets the value of the picklistid property.
     * 
     * @return
     *     possible object is
     *     {@link PICKLIST_Type }
     *     
     */
    public PICKLIST_Type getPICKLISTID() {
        return picklistid;
    }

    /**
     * Sets the value of the picklistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PICKLIST_Type }
     *     
     */
    public void setPICKLISTID(PICKLIST_Type value) {
        this.picklistid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the transactiondate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTRANSACTIONDATE() {
        return transactiondate;
    }

    /**
     * Sets the value of the transactiondate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTRANSACTIONDATE(DATETIME value) {
        this.transactiondate = value;
    }

    /**
     * Gets the value of the issueto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getISSUETO() {
        return issueto;
    }

    /**
     * Sets the value of the issueto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setISSUETO(PERSONID_Type value) {
        this.issueto = value;
    }

    /**
     * Gets the value of the advicenumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getADVICENUMBER() {
        return advicenumber;
    }

    /**
     * Sets the value of the advicenumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setADVICENUMBER(String value) {
        this.advicenumber = value;
    }

    /**
     * Gets the value of the multiequipsplitinfobatch property.
     * 
     * @return
     *     possible object is
     *     {@link MULTIEQUIPSPLITINFOBATCH }
     *     
     */
    public MULTIEQUIPSPLITINFOBATCH getMULTIEQUIPSPLITINFOBATCH() {
        return multiequipsplitinfobatch;
    }

    /**
     * Sets the value of the multiequipsplitinfobatch property.
     * 
     * @param value
     *     allowed object is
     *     {@link MULTIEQUIPSPLITINFOBATCH }
     *     
     */
    public void setMULTIEQUIPSPLITINFOBATCH(MULTIEQUIPSPLITINFOBATCH value) {
        this.multiequipsplitinfobatch = value;
    }

    /**
     * Gets the value of the issueReturnTransactionLines property.
     * 
     * @return
     *     possible object is
     *     {@link IssueReturnTransactionLines }
     *     
     */
    public IssueReturnTransactionLines getIssueReturnTransactionLines() {
        return issueReturnTransactionLines;
    }

    /**
     * Sets the value of the issueReturnTransactionLines property.
     * 
     * @param value
     *     allowed object is
     *     {@link IssueReturnTransactionLines }
     *     
     */
    public void setIssueReturnTransactionLines(IssueReturnTransactionLines value) {
        this.issueReturnTransactionLines = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
